(conditional_models)=

# Module `fwdpy11.conditional_models`

```{eval-rst}
.. automodule:: fwdpy11.conditional_models
   :members:
   :undoc-members:

.. autofunction:: fwdpy11.conditional_models.track_added_mutation

.. autofunction:: fwdpy11.conditional_models.selective_sweep
```


